# XMvn uses OSGi environment provided by Tycho, it shouldn't require
# any additional bundles.
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}^osgi\\($

# Integration tests are disabled by default, but you can run them by
# adding "--with its" to rpmbuild or mock invocation.
%bcond_with its

Name:           xmvn
Version:        2.5.0
Release:        %mkrel 11
Group:          Development/Java
Summary:        Local Extensions for Apache Maven
License:        ASL 2.0
URL:            http://mizdebsk.fedorapeople.org/xmvn
BuildArch:      noarch

Source0:        https://fedorahosted.org/released/%{name}/%{name}-%{version}.tar.xz

Patch0:         0001-Copy-core-dependencies-to-lib-core-in-assembly.patch
Patch1:         0002-Try-to-procect-builddep-MOJO-against-patological-cas.patch
Patch2:         0003-Don-t-install-POM-files-for-Tycho-projects.patch

BuildRequires:  maven-lib >= 3.3.9-2
BuildRequires:  maven-local
BuildRequires:  beust-jcommander
BuildRequires:  cglib
BuildRequires:  maven-dependency-plugin
BuildRequires:  maven-plugin-build-helper
BuildRequires:  maven-assembly-plugin
BuildRequires:  maven-install-plugin
BuildRequires:  maven-site-plugin
BuildRequires:  maven-plugin-plugin
BuildRequires:  objectweb-asm
BuildRequires:  modello
BuildRequires:  xmlunit
BuildRequires:  apache-ivy
BuildRequires:  sisu-mojos
BuildRequires:  junit
BuildRequires:  easymock
BuildRequires:  gradle >= 2.5

Requires:       xmvn-minimal = %{version}-%{release}
Requires:       maven

%description
This package provides extensions for Apache Maven that can be used to
manage system artifact repository and use it to resolve Maven
artifacts in offline mode, as well as Maven plugins to help with
creating RPM packages containing Maven artifacts.

%package        minimal
Summary:        Dependency-reduced version of XMvn
Requires:       maven-lib >= 3.2.5-2
Requires:       xmvn-api = %{version}-%{release}
Requires:       xmvn-connector-aether = %{version}-%{release}
Requires:       xmvn-core = %{version}-%{release}

%description    minimal
This package provides minimal version of XMvn, incapable of using
remote repositories.

%package        parent-pom
Summary:        XMvn Parent POM

%description    parent-pom
This package provides XMvn parent POM.

%package        api
Summary:        XMvn API

%description    api
This package provides XMvn API module which contains public interface
for functionality implemented by XMvn Core.

%package        launcher
Summary:        XMvn Launcher

%description    launcher
This package provides XMvn Launcher module, which provides a way of
launching XMvn running in isolated class realm and locating XMVn
services.

%package        core
Summary:        XMvn Core

%description    core
This package provides XMvn Core module, which implements the essential
functionality of XMvn such as resolution of artifacts from system
repository.

%package        connector-aether
Summary:        XMvn Connector for Eclipse Aether

%description    connector-aether
This package provides XMvn Connector for Eclipse Aether, which
provides integration of Eclipse Aether with XMvn.  It provides an
adapter which allows XMvn resolver to be used as Aether workspace
reader.

%package        connector-gradle
Summary:        XMvn Connector for Gradle

%description    connector-gradle
This package provides XMvn Connector for Gradle, which provides
integration of Gradle with XMvn.  It provides an adapter which allows
XMvn resolver to be used as Gradle resolver.

%package        connector-ivy
Summary:        XMvn Connector for Apache Ivy

%description    connector-ivy
This package provides XMvn Connector for Apache Ivy, which provides
integration of Apache Ivy with XMvn.  It provides an adapter which
allows XMvn resolver to be used as Ivy resolver.

%package        mojo
Summary:        XMvn MOJO

%description    mojo
This package provides XMvn MOJO, which is a Maven plugin that consists
of several MOJOs.  Some goals of these MOJOs are intended to be
attached to default Maven lifecycle when building packages, others can
be called directly from Maven command line.

%package        tools-pom
Summary:        XMvn Tools POM

%description    tools-pom
This package provides XMvn Tools parent POM.

%package        resolve
Summary:        XMvn Resolver

%description    resolve
This package provides XMvn Resolver, which is a very simple
commald-line tool to resolve Maven artifacts from system repositories.
Basically it's just an interface to artifact resolution mechanism
implemented by XMvn Core.  The primary intended use case of XMvn
Resolver is debugging local artifact repositories.

%package        bisect
Summary:        XMvn Bisect

%description    bisect
This package provides XMvn Bisect, which is a debugging tool that can
diagnose build failures by using bisection method.

%package        subst
Summary:        XMvn Subst

%description    subst
This package provides XMvn Subst, which is a tool that can substitute
Maven artifact files with symbolic links to corresponding files in
artifact repository.

%package        install
Summary:        XMvn Install

%description    install
This package provides XMvn Install, which is a command-line interface
to XMvn installer.  The installer reads reactor metadata and performs
artifact installation according to specified configuration.

%package        javadoc
Summary:        API documentation for %{name}

%description    javadoc
This package provides %{summary}.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1

%mvn_package ":xmvn{,-it}" __noinstall

%if %{without its}
%pom_disable_module xmvn-it
%endif

# remove dependency plugin maven-binaries execution
# we provide apache-maven by symlink
%pom_xpath_remove "pom:executions/pom:execution[pom:id[text()='maven-binaries']]"

# get mavenVersion that is expected
mver=$(sed -n '/<mavenVersion>/{s/.*>\(.*\)<.*/\1/;p}' \
           xmvn-parent/pom.xml)
mkdir -p target/dependency/
cp -aL %{_datadir}/maven target/dependency/apache-maven-$mver

%build
# ITs require artifacts to be insalled in local repo
%mvn_build -s -j -g install

tar --delay-directory-restore -xvf target/*tar.bz2
chmod -R +rwX %{name}-%{version}*
# These are installed as doc
rm -Rf %{name}-%{version}*/{AUTHORS,README,LICENSE,NOTICE}


%install
%mvn_install

install -d -m 755 %{buildroot}%{_datadir}/%{name}
cp -r %{name}-%{version}*/* %{buildroot}%{_datadir}/%{name}/
ln -sf %{_datadir}/maven/bin/mvn %{buildroot}%{_datadir}/%{name}/bin/mvn
ln -sf %{_datadir}/maven/bin/mvnDebug %{buildroot}%{_datadir}/%{name}/bin/mvnDebug
ln -sf %{_datadir}/maven/bin/mvnyjp %{buildroot}%{_datadir}/%{name}/bin/mvnyjp

# helper scripts
install -d -m 755 %{buildroot}%{_bindir}
for tool in subst resolve bisect install;do
    cat <<EOF >%{buildroot}%{_bindir}/%{name}-$tool
#!/bin/sh -e
exec %{_datadir}/%{name}/bin/%{name}-$tool "\${@}"
EOF
    chmod +x %{buildroot}%{_bindir}/%{name}-$tool
done

# copy over maven lib directory
cp -r %{_datadir}/maven/lib/* %{buildroot}%{_datadir}/%{name}/lib/

# possibly recreate symlinks that can be automated with xmvn-subst
%{name}-subst %{buildroot}%{_datadir}/%{name}/

# /usr/bin/xmvn script
cat <<EOF >%{buildroot}%{_bindir}/%{name}
#!/bin/sh -e
export M2_HOME="\${M2_HOME:-%{_datadir}/%{name}}"
exec %{_datadir}/maven/bin/mvn-script "\${@}"
EOF

# mvn-local symlink
ln -s %{name} %{buildroot}%{_bindir}/mvn-local

# make sure our conf is identical to maven so yum won't freak out
install -d -m 755 %{buildroot}%{_datadir}/%{name}/conf/
cp -P %{_datadir}/maven/conf/settings.xml %{buildroot}%{_datadir}/%{name}/conf/
cp -P %{_datadir}/maven/bin/m2.conf %{buildroot}%{_datadir}/%{name}/bin/

%files
%attr(755,-,-) %{_bindir}/mvn-local
%{_datadir}/%{name}/lib/aether_aether-connector-basic.jar
%{_datadir}/%{name}/lib/aether_aether-transport-wagon.jar
%{_datadir}/%{name}/lib/aopalliance.jar
%{_datadir}/%{name}/lib/cdi-apicdi-api.jar
%{_datadir}/%{name}/lib/commons-codec.jar
%{_datadir}/%{name}/lib/commons-io.jar
%{_datadir}/%{name}/lib/commons-lang.jar
%{_datadir}/%{name}/lib/commons-logging.jar
%{_datadir}/%{name}/lib/httpcomponents_httpclient.jar
%{_datadir}/%{name}/lib/httpcomponents_httpcore.jar
%{_datadir}/%{name}/lib/jsoup_jsoup.jar
%{_datadir}/%{name}/lib/jsr-305.jar
%{_datadir}/%{name}/lib/maven-wagon_file.jar
%{_datadir}/%{name}/lib/maven-wagon_http-shaded.jar
%{_datadir}/%{name}/lib/maven-wagon_http-shared.jar

%files minimal
%attr(755,-,-) %{_bindir}/%{name}
%dir %{_datadir}/%{name}/bin
%dir %{_datadir}/%{name}/lib
%exclude %{_datadir}/%{name}/lib/aether_aether-connector-basic.jar
%exclude %{_datadir}/%{name}/lib/aether_aether-transport-wagon.jar
%exclude %{_datadir}/%{name}/lib/aopalliance.jar
%exclude %{_datadir}/%{name}/lib/cdi-apicdi-api.jar
%exclude %{_datadir}/%{name}/lib/commons-codec.jar
%exclude %{_datadir}/%{name}/lib/commons-io.jar
%exclude %{_datadir}/%{name}/lib/commons-lang.jar
%exclude %{_datadir}/%{name}/lib/commons-logging.jar
%exclude %{_datadir}/%{name}/lib/httpcomponents_httpclient.jar
%exclude %{_datadir}/%{name}/lib/httpcomponents_httpcore.jar
%exclude %{_datadir}/%{name}/lib/jsoup_jsoup.jar
%exclude %{_datadir}/%{name}/lib/jsr-305.jar
%exclude %{_datadir}/%{name}/lib/maven-wagon_file.jar
%exclude %{_datadir}/%{name}/lib/maven-wagon_http-shaded.jar
%exclude %{_datadir}/%{name}/lib/maven-wagon_http-shared.jar
%{_datadir}/%{name}/lib/*.jar
%{_datadir}/%{name}/lib/ext
%{_datadir}/%{name}/bin/m2.conf
%{_datadir}/%{name}/bin/mvn
%{_datadir}/%{name}/bin/mvnDebug
%{_datadir}/%{name}/bin/mvnyjp
%{_datadir}/%{name}/bin/xmvn
%{_datadir}/%{name}/boot
%{_datadir}/%{name}/conf

%files parent-pom -f .mfiles-xmvn-parent
%doc LICENSE NOTICE

%files launcher -f .mfiles-xmvn-launcher
%dir %{_datadir}/%{name}/lib
%{_datadir}/%{name}/lib/core

%files core -f .mfiles-xmvn-core

%files api -f .mfiles-xmvn-api
%dir %{_javadir}/%{name}
%doc LICENSE NOTICE
%doc AUTHORS README

%files connector-aether -f .mfiles-xmvn-connector-aether

%files connector-gradle -f .mfiles-xmvn-connector-gradle

%files connector-ivy -f .mfiles-xmvn-connector-ivy
%dir %{_datadir}/%{name}/lib
%{_datadir}/%{name}/lib/ivy

%files mojo -f .mfiles-xmvn-mojo

%files tools-pom -f .mfiles-xmvn-tools

%files resolve -f .mfiles-xmvn-resolve
%attr(755,-,-) %{_bindir}/%{name}-resolve
%dir %{_datadir}/%{name}/bin
%dir %{_datadir}/%{name}/lib
%{_datadir}/%{name}/bin/%{name}-resolve
%{_datadir}/%{name}/lib/resolver

%files bisect -f .mfiles-xmvn-bisect
%attr(755,-,-) %{_bindir}/%{name}-bisect
%dir %{_datadir}/%{name}/bin
%dir %{_datadir}/%{name}/lib
%{_datadir}/%{name}/bin/%{name}-bisect
%{_datadir}/%{name}/lib/bisect

%files subst -f .mfiles-xmvn-subst
%attr(755,-,-) %{_bindir}/%{name}-subst
%dir %{_datadir}/%{name}/bin
%dir %{_datadir}/%{name}/lib
%{_datadir}/%{name}/bin/%{name}-subst
%{_datadir}/%{name}/lib/subst

%files install -f .mfiles-xmvn-install
%attr(755,-,-) %{_bindir}/%{name}-install
%dir %{_datadir}/%{name}/bin
%dir %{_datadir}/%{name}/lib
%{_datadir}/%{name}/bin/%{name}-install
%{_datadir}/%{name}/lib/installer

%files javadoc
%doc LICENSE NOTICE




%changelog
* Sun May 07 2017 neoclust <neoclust> 2.5.0-11.mga6
+ Revision: 1099545
- Sync with fedora 25
- Second rebuild of the java stack

* Fri Feb 26 2016 neoclust <neoclust> 2.5.0-7.mga6
+ Revision: 979357
- Rebuild against current java stack

* Wed Feb 24 2016 neoclust <neoclust> 2.5.0-6.mga6
+ Revision: 978239
- First rebuild of the java stack
- sync package xmvn with fedora
- Rebuild post-bootstrap

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

  + zezinho <zezinho>
    - bring back group an release tag
    - patch by neoclust to fix build

  + daviddavid <daviddavid>
    - sync with fc24 (update to 2.5.0)

* Fri Dec 26 2014 pterjan <pterjan> 2.0.1-4.mga5
+ Revision: 806035
- Sync with Fedora 21

* Tue Nov 04 2014 dmorgan <dmorgan> 2.0.1-3.mga5
+ Revision: 795527
- Revert to version 2.0.1

  + umeabot <umeabot>
    - Second Mageia 5 Mass Rebuild
    - Mageia 5 Mass Rebuild

* Tue Sep 09 2014 pterjan <pterjan> 2.1.0-1.mga5
+ Revision: 674084
- Add missing BuildRequires
- 2.1.0
- Sync with Fedora
- small fixes

* Sun Jun 15 2014 dmorgan <dmorgan> 1.4.0-1.mga5
+ Revision: 636587
- New version

* Sun Jun 15 2014 dmorgan <dmorgan> 1.3.0-2.mga5
+ Revision: 636322
- Rebuild against fixed maven

* Sun Jun 15 2014 dmorgan <dmorgan> 1.3.0-1.mga5
+ Revision: 636306
- New version
- New version

* Tue Oct 22 2013 umeabot <umeabot> 1.1.0-2.mga4
+ Revision: 546274
- Mageia 4 Mass Rebuild

* Mon Oct 07 2013 dmorgan <dmorgan> 1.1.0-1.mga4
+ Revision: 492400
- New version
- Restore support for relative symlinks
- Do not try to relativize symlink targets
- New version 1.0.2
- New version 0.5.1

* Sat Jul 13 2013 dmorgan <dmorgan> 0.5.0-6.mga4
+ Revision: 453593
- Use version 0.5.0 Back
- Skip tests
- New snapshot
- Version 0.4.0 Final

* Wed Jul 10 2013 dmorgan <dmorgan> 0.4.0-1.mga4
+ Revision: 452604
- Update to upstream snapshot of version 0.4.0

* Wed Jul 10 2013 dmorgan <dmorgan> 0.3.1-1.mga4
+ Revision: 452583
- Revert to version 0.3.x
- Try to set maven home dir
- Do not delete jar files
- Remove not wanted files
- Remove not wanted files

* Tue Jul 09 2013 dmorgan <dmorgan> 0.5.0-5.mga4
+ Revision: 452278
- New version

* Tue Feb 19 2013 dmorgan <dmorgan> 0.3.1-1.mga3
+ Revision: 399288
- imported package xmvn


* Thu Nov 29 2012 Mikolaj Izdebski <mizdebsk@redhat.com> - 0.0.1-1
- Update to upstream version 0.0.1

* Wed Nov 28 2012 Mikolaj Izdebski <mizdebsk@redhat.com> - 0-2
- Add jpackage scripts

* Mon Nov  5 2012 Mikolaj Izdebski <mizdebsk@redhat.com> - 0-1
- Initial packaging
